library(ggplot2)
library(showtext)
library(tidyr)
library(gridExtra)

# Set working directory
setwd("")

font_add("Jost", regular = "Scripts/Jost/Jost-400-Book.ttf")
showtext_auto() # turn on showtext auto mode
theme_set(theme_classic(base_family = "Jost")) # set Jost as the base font family

# To create stacked bars per transport option, showing the median contribution of each step to total emissions

# Read data for the grid-connected: power export configuration
dfbase <- read.csv("Derived_data/database_results.csv")

#Exclude grid-based projects
dfbase <- subset(dfbase, electricity.source != "Grid")


## 1000 km 

# Add components for conversion step pipeline 1000km
dfbase$EF_production_pipe_1000_r <- dfbase$EF_pipe_H2prod_tot_1000
dfbase$EF_conversion_pipe_1000_n <- dfbase$EF_pipe_comp1
dfbase$EF_conversion_pipe_1000_r <- dfbase$EF_pipe_comp1_tot_1000
dfbase$EF_transport_pipe_1000_n <- dfbase$EF_pipeline_1000
dfbase$EF_transport_pipe_1000_r <- dfbase$EF_pipeline_tot_1000
dfbase$EF_reconversion_pipe_1000_n <- dfbase$EF_pipe_comp2
dfbase$EF_reconversion_pipe_1000_r <- dfbase$EF_pipe_comp2
dfbase$EF_storage_pipe_1000_n <- dfbase$EF_pipe_storage
dfbase$EF_storage_pipe_1000_r <- dfbase$EF_pipe_storage


# Select the relevant columns from the database
dfpipe_long <- gather(dfbase, key = "variable", value = "value", 
                      EF_production, EF_production_pipe_1000_r, EF_conversion_pipe_1000_n, EF_conversion_pipe_1000_r,
                      EF_transport_pipe_1000_n, EF_transport_pipe_1000_r, EF_reconversion_pipe_1000_n, EF_reconversion_pipe_1000_r,
                      EF_storage_pipe_1000_n, EF_storage_pipe_1000_r)

# To go from g to kg emissions 
dfpipe_long$value <- dfpipe_long$value/1000

# Rename the selected columns for each of the process steps
dfpipe_long$variable <- ifelse(dfpipe_long$variable == "EF_production", "Production (n)",
                               ifelse(dfpipe_long$variable == "EF_production_pipe_1000_r", "Production (r)",
                                      ifelse(dfpipe_long$variable == "EF_conversion_pipe_1000_n", "Conversion (n)",
                                             ifelse(dfpipe_long$variable == "EF_conversion_pipe_1000_r", "Conversion (r)",
                                                    ifelse(dfpipe_long$variable == "EF_transport_pipe_1000_n", "Transport (n)",
                                                           ifelse(dfpipe_long$variable == "EF_transport_pipe_1000_r", "Transport (r)",
                                                                  ifelse(dfpipe_long$variable == "EF_reconversion_pipe_1000_n", "Reconversion (n)",
                                                                         ifelse(dfpipe_long$variable == "EF_reconversion_pipe_1000_r", "Reconversion (r)",
                                                                                ifelse(dfpipe_long$variable == "EF_storage_pipe_1000_n", "Storage (n)",
                                                                                       ifelse(dfpipe_long$variable == "EF_storage_pipe_1000_r", "Storage (r)", NA))))))))))


dfpipe_long$scenario <- ifelse(dfpipe_long$variable %in% c("Production (n)", "Conversion (n)", "Transport (n)", "Reconversion (n)", "Storage (n)"), "Pipeline (n)",
                               ifelse(dfpipe_long$variable %in% c("Production (r)", "Conversion (r)", "Transport (r)", "Reconversion (r)", "Storage (r)"), "Pipeline (r)", NA))


dfpipe_long_1000 <- dfpipe_long[, c("reference", "value", "variable", "scenario")]



######## LH2
# Add components for conversion step LH2 1000km

dfbase$EF_production_LH2_1000_r <- dfbase$EF_LH2_H2prod_tot_1000
dfbase$EF_conversion_LH2_1000_n <- dfbase$EF_LH2_liqf + dfbase$EF_LH2_storage + dfbase$EF_LH2_loading
dfbase$EF_conversion_LH2_1000_r <- dfbase$EF_LH2_liqf_tot_1000 + dfbase$EF_LH2_storage_tot_1000 + dfbase$EF_LH2_loading_tot_1000
dfbase$EF_transport_LH2_1000_n <- dfbase$EF_LH2_ship_1000 
dfbase$EF_transport_LH2_1000_r <- dfbase$EF_LH2_ship_tot_1000
dfbase$EF_reconversion_LH2_1000_n <- dfbase$EF_LH2_unloading + dfbase$EF_LH2_regas_comp
dfbase$EF_reconversion_LH2_1000_r <- dfbase$EF_LH2_unloading_tot_1000 + dfbase$EF_LH2_regas_comp
dfbase$EF_storage_LH2_1000_n <- dfbase$EF_LH2_H2g_storage
dfbase$EF_storage_LH2_1000_r <- dfbase$EF_LH2_H2g_storage

# Select the relevant columns from the database
dfLH2_long <- gather(dfbase, key = "variable", value = "value", 
                     EF_production, EF_production_LH2_1000_r, EF_conversion_LH2_1000_n, EF_conversion_LH2_1000_r,
                     EF_transport_LH2_1000_n, EF_transport_LH2_1000_r, EF_reconversion_LH2_1000_n, EF_reconversion_LH2_1000_r,
                     EF_storage_LH2_1000_n, EF_storage_LH2_1000_r)

# To go from g to kg emissions 
dfLH2_long$value <- dfLH2_long$value/1000

# Rename the selected columns for each of the process steps
dfLH2_long$variable <- ifelse(dfLH2_long$variable == "EF_production", "Production (n)",
                              ifelse(dfLH2_long$variable == "EF_production_LH2_1000_r", "Production (r)",
                                     ifelse(dfLH2_long$variable == "EF_conversion_LH2_1000_n", "Conversion (n)",
                                            ifelse(dfLH2_long$variable == "EF_conversion_LH2_1000_r", "Conversion (r)",
                                                   ifelse(dfLH2_long$variable == "EF_transport_LH2_1000_n", "Transport (n)",
                                                          ifelse(dfLH2_long$variable == "EF_transport_LH2_1000_r", "Transport (r)",
                                                                 ifelse(dfLH2_long$variable == "EF_reconversion_LH2_1000_n", "Reconversion (n)",
                                                                        ifelse(dfLH2_long$variable == "EF_reconversion_LH2_1000_r", "Reconversion (r)",
                                                                               ifelse(dfLH2_long$variable == "EF_storage_LH2_1000_n", "Storage (n)",
                                                                                      ifelse(dfLH2_long$variable == "EF_storage_LH2_1000_r", "Storage (r)", NA))))))))))


dfLH2_long$scenario <- ifelse(dfLH2_long$variable %in% c("Production (n)", "Conversion (n)", "Transport (n)", "Reconversion (n)", "Storage (n)"), "Liquid hydrogen (n)",
                              ifelse(dfLH2_long$variable %in% c("Production (r)", "Conversion (r)", "Transport (r)", "Reconversion (r)", "Storage (r)"), "Liquid hydrogen (r)", NA))


dfLH2_long_1000 <- dfLH2_long[, c("reference", "value", "variable", "scenario")]

###### NH3 without cracking
dfbase$EF_production_NH3S_1000_r <- dfbase$EF_NH3_prod_H2_S_tot_1000
dfbase$EF_conversion_NH3S_1000_n <- dfbase$EF_NH3_precomp_1 + dfbase$EF_NH3_prod_1 + dfbase$EF_NH3_loading
dfbase$EF_conversion_NH3S_1000_r <- dfbase$EF_NH3_precomp_1 + dfbase$EF_NH3_precomp_1_S_add_1000 + dfbase$EF_NH3_prod_1 + dfbase$EF_NH3_prod_1_S_add_1000 + dfbase$EF_NH3_loading + dfbase$EF_NH3_loading_S_add_1000
dfbase$EF_transport_NH3S_1000_n <- dfbase$EF_NH3_ship_1000 
dfbase$EF_transport_NH3S_1000_r <- dfbase$EF_NH3_ship_1000 + dfbase$EF_NH3_ship_S_add_1000
dfbase$EF_reconversion_NH3S_1000_n <- 0
dfbase$EF_reconversion_NH3S_1000_r <- 0
dfbase$EF_storage_NH3S_1000_n <- dfbase$EF_NH3_unloading_storage
dfbase$EF_storage_NH3S_1000_r <- dfbase$EF_NH3_unloading_storage

# Select the relevant columns from the database
dfNH3S_long <- gather(dfbase, key = "variable", value = "value", 
                      EF_production, EF_production_NH3S_1000_r, EF_conversion_NH3S_1000_n, EF_conversion_NH3S_1000_r,
                      EF_transport_NH3S_1000_n, EF_transport_NH3S_1000_r, EF_reconversion_NH3S_1000_n, EF_reconversion_NH3S_1000_r,
                      EF_storage_NH3S_1000_n, EF_storage_NH3S_1000_r)

# To go from g to kg emissions 
dfNH3S_long$value <- dfNH3S_long$value/1000

# Rename the selected columns for each of the process steps
dfNH3S_long$variable <- ifelse(dfNH3S_long$variable == "EF_production", "Production (n)",
                               ifelse(dfNH3S_long$variable == "EF_production_NH3S_1000_r", "Production (r)",
                                      ifelse(dfNH3S_long$variable == "EF_conversion_NH3S_1000_n", "Conversion (n)",
                                             ifelse(dfNH3S_long$variable == "EF_conversion_NH3S_1000_r", "Conversion (r)",
                                                    ifelse(dfNH3S_long$variable == "EF_transport_NH3S_1000_n", "Transport (n)",
                                                           ifelse(dfNH3S_long$variable == "EF_transport_NH3S_1000_r", "Transport (r)",
                                                                  ifelse(dfNH3S_long$variable == "EF_reconversion_NH3S_1000_n", "Reconversion (n)",
                                                                         ifelse(dfNH3S_long$variable == "EF_reconversion_NH3S_1000_r", "Reconversion (r)",
                                                                                ifelse(dfNH3S_long$variable == "EF_storage_NH3S_1000_n", "Storage (n)",
                                                                                       ifelse(dfNH3S_long$variable == "EF_storage_NH3S_1000_r", "Storage (r)", NA))))))))))


dfNH3S_long$scenario <- ifelse(dfNH3S_long$variable %in% c("Production (n)", "Conversion (n)", "Transport (n)", "Reconversion (n)", "Storage (n)"), "Ammonia without cracking (n)",
                               ifelse(dfNH3S_long$variable %in% c("Production (r)", "Conversion (r)", "Transport (r)", "Reconversion (r)", "Storage (r)"), "Ammonia without cracking (r)", NA))


dfNH3S_long_1000 <- dfNH3S_long[, c("reference", "value", "variable", "scenario")]

##### NH3 with cracking
dfbase$EF_production_NH3C_1000_r <- dfbase$EF_NH3_prod_H2_C_tot_1000
dfbase$EF_conversion_NH3C_1000_n <- dfbase$EF_NH3_precomp_1 + dfbase$EF_NH3_prod_1 + dfbase$EF_NH3_loading
dfbase$EF_conversion_NH3C_1000_r <- dfbase$EF_NH3_precomp_1 + dfbase$EF_NH3_precomp_1_C_add_1000 + dfbase$EF_NH3_prod_1 + dfbase$EF_NH3_prod_1_C_add_1000 + dfbase$EF_NH3_loading + dfbase$EF_NH3_loading_C_add_1000
dfbase$EF_transport_NH3C_1000_n <- dfbase$EF_NH3_ship_1000 
dfbase$EF_transport_NH3C_1000_r <- dfbase$EF_NH3_ship_1000 + dfbase$EF_NH3_ship_C_add_1000
dfbase$EF_reconversion_NH3C_1000_n <- dfbase$EF_NH3_unloading + dfbase$EF_NH3_cracking + dfbase$EF_NH3_H2_comp
dfbase$EF_reconversion_NH3C_1000_r <- dfbase$EF_NH3_unloading + dfbase$EF_NH3_unloading_add_1000 + dfbase$EF_NH3_cracking + dfbase$EF_NH3_crack_add_1000 + dfbase$EF_NH3_H2_comp
dfbase$EF_storage_NH3C_1000_n <- dfbase$EF_NH3_H2_storage
dfbase$EF_storage_NH3C_1000_r <- dfbase$EF_NH3_H2_storage



# Select the relevant columns from the database
dfNH3C_long <- gather(dfbase, key = "variable", value = "value", 
                      EF_production, EF_production_NH3C_1000_r, EF_conversion_NH3C_1000_n, EF_conversion_NH3C_1000_r,
                      EF_transport_NH3C_1000_n, EF_transport_NH3C_1000_r, EF_reconversion_NH3C_1000_n, EF_reconversion_NH3C_1000_r,
                      EF_storage_NH3C_1000_n, EF_storage_NH3C_1000_r)

# To go from g to kg emissions 
dfNH3C_long$value <- dfNH3C_long$value/1000

# Rename the selected columns for each of the process steps
dfNH3C_long$variable <- ifelse(dfNH3C_long$variable == "EF_production", "Production (n)",
                               ifelse(dfNH3C_long$variable == "EF_production_NH3C_1000_r", "Production (r)",
                                      ifelse(dfNH3C_long$variable == "EF_conversion_NH3C_1000_n", "Conversion (n)",
                                             ifelse(dfNH3C_long$variable == "EF_conversion_NH3C_1000_r", "Conversion (r)",
                                                    ifelse(dfNH3C_long$variable == "EF_transport_NH3C_1000_n", "Transport (n)",
                                                           ifelse(dfNH3C_long$variable == "EF_transport_NH3C_1000_r", "Transport (r)",
                                                                  ifelse(dfNH3C_long$variable == "EF_reconversion_NH3C_1000_n", "Reconversion (n)",
                                                                         ifelse(dfNH3C_long$variable == "EF_reconversion_NH3C_1000_r", "Reconversion (r)",
                                                                                ifelse(dfNH3C_long$variable == "EF_storage_NH3C_1000_n", "Storage (n)",
                                                                                       ifelse(dfNH3C_long$variable == "EF_storage_NH3C_1000_r", "Storage (r)", NA))))))))))


dfNH3C_long$scenario <- ifelse(dfNH3C_long$variable %in% c("Production (n)", "Conversion (n)", "Transport (n)", "Reconversion (n)", "Storage (n)"), "Ammonia with cracking (n)",
                               ifelse(dfNH3C_long$variable %in% c("Production (r)", "Conversion (r)", "Transport (r)", "Reconversion (r)", "Storage (r)"), "Ammonia with cracking (r)", NA))


dfNH3C_long_1000 <- dfNH3C_long[, c("reference", "value", "variable", "scenario")]


#Merge the dataframes
database_long_1000 <- rbind(dfpipe_long_1000, dfLH2_long_1000, dfNH3S_long_1000, dfNH3C_long_1000)

database_long_1000$distance <- "1,000"


# Now 5000 km.

# Add components for conversion step pipeline 5000km
dfbase$EF_production_pipe_5000_r <- dfbase$EF_pipe_H2prod_tot_5000
dfbase$EF_conversion_pipe_5000_n <- dfbase$EF_pipe_comp1
dfbase$EF_conversion_pipe_5000_r <- dfbase$EF_pipe_comp1_tot_5000
dfbase$EF_transport_pipe_5000_n <- dfbase$EF_pipeline_5000
dfbase$EF_transport_pipe_5000_r <- dfbase$EF_pipeline_tot_5000
dfbase$EF_reconversion_pipe_5000_n <- dfbase$EF_pipe_comp2
dfbase$EF_reconversion_pipe_5000_r <- dfbase$EF_pipe_comp2
dfbase$EF_storage_pipe_5000_n <- dfbase$EF_pipe_storage
dfbase$EF_storage_pipe_5000_r <- dfbase$EF_pipe_storage


# Select the relevant columns from the database
dfpipe_long <- gather(dfbase, key = "variable", value = "value", 
                      EF_production, EF_production_pipe_5000_r, EF_conversion_pipe_5000_n, EF_conversion_pipe_5000_r,
                      EF_transport_pipe_5000_n, EF_transport_pipe_5000_r, EF_reconversion_pipe_5000_n, EF_reconversion_pipe_5000_r,
                      EF_storage_pipe_5000_n, EF_storage_pipe_5000_r)

# To go from g to kg emissions 
dfpipe_long$value <- dfpipe_long$value/1000

# Rename the selected columns for each of the process steps
dfpipe_long$variable <- ifelse(dfpipe_long$variable == "EF_production", "Production (n)",
                               ifelse(dfpipe_long$variable == "EF_production_pipe_5000_r", "Production (r)",
                                      ifelse(dfpipe_long$variable == "EF_conversion_pipe_5000_n", "Conversion (n)",
                                             ifelse(dfpipe_long$variable == "EF_conversion_pipe_5000_r", "Conversion (r)",
                                                    ifelse(dfpipe_long$variable == "EF_transport_pipe_5000_n", "Transport (n)",
                                                           ifelse(dfpipe_long$variable == "EF_transport_pipe_5000_r", "Transport (r)",
                                                                  ifelse(dfpipe_long$variable == "EF_reconversion_pipe_5000_n", "Reconversion (n)",
                                                                         ifelse(dfpipe_long$variable == "EF_reconversion_pipe_5000_r", "Reconversion (r)",
                                                                                ifelse(dfpipe_long$variable == "EF_storage_pipe_5000_n", "Storage (n)",
                                                                                       ifelse(dfpipe_long$variable == "EF_storage_pipe_5000_r", "Storage (r)", NA))))))))))


dfpipe_long$scenario <- ifelse(dfpipe_long$variable %in% c("Production (n)", "Conversion (n)", "Transport (n)", "Reconversion (n)", "Storage (n)"), "Pipeline (n)",
                               ifelse(dfpipe_long$variable %in% c("Production (r)", "Conversion (r)", "Transport (r)", "Reconversion (r)", "Storage (r)"), "Pipeline (r)", NA))


dfpipe_long_5000 <- dfpipe_long[, c("reference", "value", "variable", "scenario")]



######## LH2
# Add components for conversion step LH2 5000km

dfbase$EF_production_LH2_5000_r <- dfbase$EF_LH2_H2prod_tot_5000
dfbase$EF_conversion_LH2_5000_n <- dfbase$EF_LH2_liqf + dfbase$EF_LH2_storage + dfbase$EF_LH2_loading
dfbase$EF_conversion_LH2_5000_r <- dfbase$EF_LH2_liqf_tot_5000 + dfbase$EF_LH2_storage_tot_5000 + dfbase$EF_LH2_loading_tot_5000
dfbase$EF_transport_LH2_5000_n <- dfbase$EF_LH2_ship_5000 
dfbase$EF_transport_LH2_5000_r <- dfbase$EF_LH2_ship_tot_5000
dfbase$EF_reconversion_LH2_5000_n <- dfbase$EF_LH2_unloading + dfbase$EF_LH2_regas_comp
dfbase$EF_reconversion_LH2_5000_r <- dfbase$EF_LH2_unloading_tot_5000 + dfbase$EF_LH2_regas_comp
dfbase$EF_storage_LH2_5000_n <- dfbase$EF_LH2_H2g_storage
dfbase$EF_storage_LH2_5000_r <- dfbase$EF_LH2_H2g_storage

# Select the relevant columns from the database
dfLH2_long <- gather(dfbase, key = "variable", value = "value", 
                     EF_production, EF_production_LH2_5000_r, EF_conversion_LH2_5000_n, EF_conversion_LH2_5000_r,
                     EF_transport_LH2_5000_n, EF_transport_LH2_5000_r, EF_reconversion_LH2_5000_n, EF_reconversion_LH2_5000_r,
                     EF_storage_LH2_5000_n, EF_storage_LH2_5000_r)

# To go from g to kg emissions 
dfLH2_long$value <- dfLH2_long$value/1000

# Rename the selected columns for each of the process steps
dfLH2_long$variable <- ifelse(dfLH2_long$variable == "EF_production", "Production (n)",
                              ifelse(dfLH2_long$variable == "EF_production_LH2_5000_r", "Production (r)",
                                     ifelse(dfLH2_long$variable == "EF_conversion_LH2_5000_n", "Conversion (n)",
                                            ifelse(dfLH2_long$variable == "EF_conversion_LH2_5000_r", "Conversion (r)",
                                                   ifelse(dfLH2_long$variable == "EF_transport_LH2_5000_n", "Transport (n)",
                                                          ifelse(dfLH2_long$variable == "EF_transport_LH2_5000_r", "Transport (r)",
                                                                 ifelse(dfLH2_long$variable == "EF_reconversion_LH2_5000_n", "Reconversion (n)",
                                                                        ifelse(dfLH2_long$variable == "EF_reconversion_LH2_5000_r", "Reconversion (r)",
                                                                               ifelse(dfLH2_long$variable == "EF_storage_LH2_5000_n", "Storage (n)",
                                                                                      ifelse(dfLH2_long$variable == "EF_storage_LH2_5000_r", "Storage (r)", NA))))))))))


dfLH2_long$scenario <- ifelse(dfLH2_long$variable %in% c("Production (n)", "Conversion (n)", "Transport (n)", "Reconversion (n)", "Storage (n)"), "Liquid hydrogen (n)",
                              ifelse(dfLH2_long$variable %in% c("Production (r)", "Conversion (r)", "Transport (r)", "Reconversion (r)", "Storage (r)"), "Liquid hydrogen (r)", NA))


dfLH2_long_5000 <- dfLH2_long[, c("reference", "value", "variable", "scenario")]

###### NH3 without cracking
dfbase$EF_production_NH3S_5000_r <- dfbase$EF_NH3_prod_H2_S_tot_5000
dfbase$EF_conversion_NH3S_5000_n <- dfbase$EF_NH3_precomp_1 + dfbase$EF_NH3_prod_1 + dfbase$EF_NH3_loading
dfbase$EF_conversion_NH3S_5000_r <- dfbase$EF_NH3_precomp_1 + dfbase$EF_NH3_precomp_1_S_add_5000 + dfbase$EF_NH3_prod_1 + dfbase$EF_NH3_prod_1_S_add_5000 + dfbase$EF_NH3_loading + dfbase$EF_NH3_loading_S_add_5000
dfbase$EF_transport_NH3S_5000_n <- dfbase$EF_NH3_ship_5000 
dfbase$EF_transport_NH3S_5000_r <- dfbase$EF_NH3_ship_5000 + dfbase$EF_NH3_ship_S_add_5000
dfbase$EF_reconversion_NH3S_5000_n <- 0
dfbase$EF_reconversion_NH3S_5000_r <- 0
dfbase$EF_storage_NH3S_5000_n <- dfbase$EF_NH3_unloading_storage
dfbase$EF_storage_NH3S_5000_r <- dfbase$EF_NH3_unloading_storage

# Select the relevant columns from the database
dfNH3S_long <- gather(dfbase, key = "variable", value = "value", 
                      EF_production, EF_production_NH3S_5000_r, EF_conversion_NH3S_5000_n, EF_conversion_NH3S_5000_r,
                      EF_transport_NH3S_5000_n, EF_transport_NH3S_5000_r, EF_reconversion_NH3S_5000_n, EF_reconversion_NH3S_5000_r,
                      EF_storage_NH3S_5000_n, EF_storage_NH3S_5000_r)

# To go from g to kg emissions 
dfNH3S_long$value <- dfNH3S_long$value/1000

# Rename the selected columns for each of the process steps
dfNH3S_long$variable <- ifelse(dfNH3S_long$variable == "EF_production", "Production (n)",
                               ifelse(dfNH3S_long$variable == "EF_production_NH3S_5000_r", "Production (r)",
                                      ifelse(dfNH3S_long$variable == "EF_conversion_NH3S_5000_n", "Conversion (n)",
                                             ifelse(dfNH3S_long$variable == "EF_conversion_NH3S_5000_r", "Conversion (r)",
                                                    ifelse(dfNH3S_long$variable == "EF_transport_NH3S_5000_n", "Transport (n)",
                                                           ifelse(dfNH3S_long$variable == "EF_transport_NH3S_5000_r", "Transport (r)",
                                                                  ifelse(dfNH3S_long$variable == "EF_reconversion_NH3S_5000_n", "Reconversion (n)",
                                                                         ifelse(dfNH3S_long$variable == "EF_reconversion_NH3S_5000_r", "Reconversion (r)",
                                                                                ifelse(dfNH3S_long$variable == "EF_storage_NH3S_5000_n", "Storage (n)",
                                                                                       ifelse(dfNH3S_long$variable == "EF_storage_NH3S_5000_r", "Storage (r)", NA))))))))))


dfNH3S_long$scenario <- ifelse(dfNH3S_long$variable %in% c("Production (n)", "Conversion (n)", "Transport (n)", "Reconversion (n)", "Storage (n)"), "Ammonia without cracking (n)",
                               ifelse(dfNH3S_long$variable %in% c("Production (r)", "Conversion (r)", "Transport (r)", "Reconversion (r)", "Storage (r)"), "Ammonia without cracking (r)", NA))


dfNH3S_long_5000 <- dfNH3S_long[, c("reference", "value", "variable", "scenario")]

##### NH3 with cracking
dfbase$EF_production_NH3C_5000_r <- dfbase$EF_NH3_prod_H2_C_tot_5000
dfbase$EF_conversion_NH3C_5000_n <- dfbase$EF_NH3_precomp_1 + dfbase$EF_NH3_prod_1 + dfbase$EF_NH3_loading
dfbase$EF_conversion_NH3C_5000_r <- dfbase$EF_NH3_precomp_1 + dfbase$EF_NH3_precomp_1_C_add_5000 + dfbase$EF_NH3_prod_1 + dfbase$EF_NH3_prod_1_C_add_5000 + dfbase$EF_NH3_loading + dfbase$EF_NH3_loading_C_add_5000
dfbase$EF_transport_NH3C_5000_n <- dfbase$EF_NH3_ship_5000 
dfbase$EF_transport_NH3C_5000_r <- dfbase$EF_NH3_ship_5000 + dfbase$EF_NH3_ship_C_add_5000
dfbase$EF_reconversion_NH3C_5000_n <- dfbase$EF_NH3_unloading + dfbase$EF_NH3_cracking + dfbase$EF_NH3_H2_comp
dfbase$EF_reconversion_NH3C_5000_r <- dfbase$EF_NH3_unloading + dfbase$EF_NH3_unloading_add_5000 + dfbase$EF_NH3_cracking + dfbase$EF_NH3_crack_add_5000 + dfbase$EF_NH3_H2_comp
dfbase$EF_storage_NH3C_5000_n <- dfbase$EF_NH3_H2_storage
dfbase$EF_storage_NH3C_5000_r <- dfbase$EF_NH3_H2_storage



# Select the relevant columns from the database
dfNH3C_long <- gather(dfbase, key = "variable", value = "value", 
                      EF_production, EF_production_NH3C_5000_r, EF_conversion_NH3C_5000_n, EF_conversion_NH3C_5000_r,
                      EF_transport_NH3C_5000_n, EF_transport_NH3C_5000_r, EF_reconversion_NH3C_5000_n, EF_reconversion_NH3C_5000_r,
                      EF_storage_NH3C_5000_n, EF_storage_NH3C_5000_r)

# To go from g to kg emissions 
dfNH3C_long$value <- dfNH3C_long$value/1000

# Rename the selected columns for each of the process steps
dfNH3C_long$variable <- ifelse(dfNH3C_long$variable == "EF_production", "Production (n)",
                               ifelse(dfNH3C_long$variable == "EF_production_NH3C_5000_r", "Production (r)",
                                      ifelse(dfNH3C_long$variable == "EF_conversion_NH3C_5000_n", "Conversion (n)",
                                             ifelse(dfNH3C_long$variable == "EF_conversion_NH3C_5000_r", "Conversion (r)",
                                                    ifelse(dfNH3C_long$variable == "EF_transport_NH3C_5000_n", "Transport (n)",
                                                           ifelse(dfNH3C_long$variable == "EF_transport_NH3C_5000_r", "Transport (r)",
                                                                  ifelse(dfNH3C_long$variable == "EF_reconversion_NH3C_5000_n", "Reconversion (n)",
                                                                         ifelse(dfNH3C_long$variable == "EF_reconversion_NH3C_5000_r", "Reconversion (r)",
                                                                                ifelse(dfNH3C_long$variable == "EF_storage_NH3C_5000_n", "Storage (n)",
                                                                                       ifelse(dfNH3C_long$variable == "EF_storage_NH3C_5000_r", "Storage (r)", NA))))))))))


dfNH3C_long$scenario <- ifelse(dfNH3C_long$variable %in% c("Production (n)", "Conversion (n)", "Transport (n)", "Reconversion (n)", "Storage (n)"), "Ammonia with cracking (n)",
                               ifelse(dfNH3C_long$variable %in% c("Production (r)", "Conversion (r)", "Transport (r)", "Reconversion (r)", "Storage (r)"), "Ammonia with cracking (r)", NA))


dfNH3C_long_5000 <- dfNH3C_long[, c("reference", "value", "variable", "scenario")]


#Merge the dataframes
database_long_5000 <- rbind(dfpipe_long_5000, dfLH2_long_5000, dfNH3S_long_5000, dfNH3C_long_5000)

database_long_5000$distance <- "5,000"

############

## Now 20000 km, which doesn't have a pipeline option. 

######## LH2
# Add components for conversion step LH2 20000km

dfbase$EF_production_LH2_20000_r <- dfbase$EF_LH2_H2prod_tot_20000
dfbase$EF_conversion_LH2_20000_n <- dfbase$EF_LH2_liqf + dfbase$EF_LH2_storage + dfbase$EF_LH2_loading
dfbase$EF_conversion_LH2_20000_r <- dfbase$EF_LH2_liqf_tot_20000 + dfbase$EF_LH2_storage_tot_20000 + dfbase$EF_LH2_loading_tot_20000
dfbase$EF_transport_LH2_20000_n <- dfbase$EF_LH2_ship_20000 
dfbase$EF_transport_LH2_20000_r <- dfbase$EF_LH2_ship_tot_20000
dfbase$EF_reconversion_LH2_20000_n <- dfbase$EF_LH2_unloading + dfbase$EF_LH2_regas_comp
dfbase$EF_reconversion_LH2_20000_r <- dfbase$EF_LH2_unloading_tot_20000 + dfbase$EF_LH2_regas_comp
dfbase$EF_storage_LH2_20000_n <- dfbase$EF_LH2_H2g_storage
dfbase$EF_storage_LH2_20000_r <- dfbase$EF_LH2_H2g_storage

# Select the relevant columns from the database
dfLH2_long <- gather(dfbase, key = "variable", value = "value", 
                     EF_production, EF_production_LH2_20000_r, EF_conversion_LH2_20000_n, EF_conversion_LH2_20000_r,
                     EF_transport_LH2_20000_n, EF_transport_LH2_20000_r, EF_reconversion_LH2_20000_n, EF_reconversion_LH2_20000_r,
                     EF_storage_LH2_20000_n, EF_storage_LH2_20000_r)

# To go from g to kg emissions 
dfLH2_long$value <- dfLH2_long$value/1000

# Rename the selected columns for each of the process steps
dfLH2_long$variable <- ifelse(dfLH2_long$variable == "EF_production", "Production (n)",
                              ifelse(dfLH2_long$variable == "EF_production_LH2_20000_r", "Production (r)",
                                     ifelse(dfLH2_long$variable == "EF_conversion_LH2_20000_n", "Conversion (n)",
                                            ifelse(dfLH2_long$variable == "EF_conversion_LH2_20000_r", "Conversion (r)",
                                                   ifelse(dfLH2_long$variable == "EF_transport_LH2_20000_n", "Transport (n)",
                                                          ifelse(dfLH2_long$variable == "EF_transport_LH2_20000_r", "Transport (r)",
                                                                 ifelse(dfLH2_long$variable == "EF_reconversion_LH2_20000_n", "Reconversion (n)",
                                                                        ifelse(dfLH2_long$variable == "EF_reconversion_LH2_20000_r", "Reconversion (r)",
                                                                               ifelse(dfLH2_long$variable == "EF_storage_LH2_20000_n", "Storage (n)",
                                                                                      ifelse(dfLH2_long$variable == "EF_storage_LH2_20000_r", "Storage (r)", NA))))))))))


dfLH2_long$scenario <- ifelse(dfLH2_long$variable %in% c("Production (n)", "Conversion (n)", "Transport (n)", "Reconversion (n)", "Storage (n)"), "Liquid hydrogen (n)",
                              ifelse(dfLH2_long$variable %in% c("Production (r)", "Conversion (r)", "Transport (r)", "Reconversion (r)", "Storage (r)"), "Liquid hydrogen (r)", NA))


dfLH2_long_20000 <- dfLH2_long[, c("reference", "value", "variable", "scenario")]

###### NH3 without cracking
dfbase$EF_production_NH3S_20000_r <- dfbase$EF_NH3_prod_H2_S_tot_20000
dfbase$EF_conversion_NH3S_20000_n <- dfbase$EF_NH3_precomp_1 + dfbase$EF_NH3_prod_1 + dfbase$EF_NH3_loading
dfbase$EF_conversion_NH3S_20000_r <- dfbase$EF_NH3_precomp_1 + dfbase$EF_NH3_precomp_1_S_add_20000 + dfbase$EF_NH3_prod_1 + dfbase$EF_NH3_prod_1_S_add_20000 + dfbase$EF_NH3_loading + dfbase$EF_NH3_loading_S_add_20000
dfbase$EF_transport_NH3S_20000_n <- dfbase$EF_NH3_ship_20000 
dfbase$EF_transport_NH3S_20000_r <- dfbase$EF_NH3_ship_20000 + dfbase$EF_NH3_ship_S_add_20000
dfbase$EF_reconversion_NH3S_20000_n <- 0
dfbase$EF_reconversion_NH3S_20000_r <- 0
dfbase$EF_storage_NH3S_20000_n <- dfbase$EF_NH3_unloading_storage
dfbase$EF_storage_NH3S_20000_r <- dfbase$EF_NH3_unloading_storage

# Select the relevant columns from the database
dfNH3S_long <- gather(dfbase, key = "variable", value = "value", 
                      EF_production, EF_production_NH3S_20000_r, EF_conversion_NH3S_20000_n, EF_conversion_NH3S_20000_r,
                      EF_transport_NH3S_20000_n, EF_transport_NH3S_20000_r, EF_reconversion_NH3S_20000_n, EF_reconversion_NH3S_20000_r,
                      EF_storage_NH3S_20000_n, EF_storage_NH3S_20000_r)

# To go from g to kg emissions 
dfNH3S_long$value <- dfNH3S_long$value/1000

# Rename the selected columns for each of the process steps
dfNH3S_long$variable <- ifelse(dfNH3S_long$variable == "EF_production", "Production (n)",
                               ifelse(dfNH3S_long$variable == "EF_production_NH3S_20000_r", "Production (r)",
                                      ifelse(dfNH3S_long$variable == "EF_conversion_NH3S_20000_n", "Conversion (n)",
                                             ifelse(dfNH3S_long$variable == "EF_conversion_NH3S_20000_r", "Conversion (r)",
                                                    ifelse(dfNH3S_long$variable == "EF_transport_NH3S_20000_n", "Transport (n)",
                                                           ifelse(dfNH3S_long$variable == "EF_transport_NH3S_20000_r", "Transport (r)",
                                                                  ifelse(dfNH3S_long$variable == "EF_reconversion_NH3S_20000_n", "Reconversion (n)",
                                                                         ifelse(dfNH3S_long$variable == "EF_reconversion_NH3S_20000_r", "Reconversion (r)",
                                                                                ifelse(dfNH3S_long$variable == "EF_storage_NH3S_20000_n", "Storage (n)",
                                                                                       ifelse(dfNH3S_long$variable == "EF_storage_NH3S_20000_r", "Storage (r)", NA))))))))))


dfNH3S_long$scenario <- ifelse(dfNH3S_long$variable %in% c("Production (n)", "Conversion (n)", "Transport (n)", "Reconversion (n)", "Storage (n)"), "Ammonia without cracking (n)",
                               ifelse(dfNH3S_long$variable %in% c("Production (r)", "Conversion (r)", "Transport (r)", "Reconversion (r)", "Storage (r)"), "Ammonia without cracking (r)", NA))


dfNH3S_long_20000 <- dfNH3S_long[, c("reference", "value", "variable", "scenario")]

##### NH3 with cracking
dfbase$EF_production_NH3C_20000_r <- dfbase$EF_NH3_prod_H2_C_tot_20000
dfbase$EF_conversion_NH3C_20000_n <- dfbase$EF_NH3_precomp_1 + dfbase$EF_NH3_prod_1 + dfbase$EF_NH3_loading
dfbase$EF_conversion_NH3C_20000_r <- dfbase$EF_NH3_precomp_1 + dfbase$EF_NH3_precomp_1_C_add_20000 + dfbase$EF_NH3_prod_1 + dfbase$EF_NH3_prod_1_C_add_20000 + dfbase$EF_NH3_loading + dfbase$EF_NH3_loading_C_add_20000
dfbase$EF_transport_NH3C_20000_n <- dfbase$EF_NH3_ship_20000 
dfbase$EF_transport_NH3C_20000_r <- dfbase$EF_NH3_ship_20000 + dfbase$EF_NH3_ship_C_add_20000
dfbase$EF_reconversion_NH3C_20000_n <- dfbase$EF_NH3_unloading + dfbase$EF_NH3_cracking + dfbase$EF_NH3_H2_comp
dfbase$EF_reconversion_NH3C_20000_r <- dfbase$EF_NH3_unloading + dfbase$EF_NH3_unloading_add_20000 + dfbase$EF_NH3_cracking + dfbase$EF_NH3_crack_add_20000 + dfbase$EF_NH3_H2_comp
dfbase$EF_storage_NH3C_20000_n <- dfbase$EF_NH3_H2_storage
dfbase$EF_storage_NH3C_20000_r <- dfbase$EF_NH3_H2_storage



# Select the relevant columns from the database
dfNH3C_long <- gather(dfbase, key = "variable", value = "value", 
                      EF_production, EF_production_NH3C_20000_r, EF_conversion_NH3C_20000_n, EF_conversion_NH3C_20000_r,
                      EF_transport_NH3C_20000_n, EF_transport_NH3C_20000_r, EF_reconversion_NH3C_20000_n, EF_reconversion_NH3C_20000_r,
                      EF_storage_NH3C_20000_n, EF_storage_NH3C_20000_r)

# To go from g to kg emissions 
dfNH3C_long$value <- dfNH3C_long$value/1000

# Rename the selected columns for each of the process steps
dfNH3C_long$variable <- ifelse(dfNH3C_long$variable == "EF_production", "Production (n)",
                               ifelse(dfNH3C_long$variable == "EF_production_NH3C_20000_r", "Production (r)",
                                      ifelse(dfNH3C_long$variable == "EF_conversion_NH3C_20000_n", "Conversion (n)",
                                             ifelse(dfNH3C_long$variable == "EF_conversion_NH3C_20000_r", "Conversion (r)",
                                                    ifelse(dfNH3C_long$variable == "EF_transport_NH3C_20000_n", "Transport (n)",
                                                           ifelse(dfNH3C_long$variable == "EF_transport_NH3C_20000_r", "Transport (r)",
                                                                  ifelse(dfNH3C_long$variable == "EF_reconversion_NH3C_20000_n", "Reconversion (n)",
                                                                         ifelse(dfNH3C_long$variable == "EF_reconversion_NH3C_20000_r", "Reconversion (r)",
                                                                                ifelse(dfNH3C_long$variable == "EF_storage_NH3C_20000_n", "Storage (n)",
                                                                                       ifelse(dfNH3C_long$variable == "EF_storage_NH3C_20000_r", "Storage (r)", NA))))))))))


dfNH3C_long$scenario <- ifelse(dfNH3C_long$variable %in% c("Production (n)", "Conversion (n)", "Transport (n)", "Reconversion (n)", "Storage (n)"), "Ammonia with cracking (n)",
                               ifelse(dfNH3C_long$variable %in% c("Production (r)", "Conversion (r)", "Transport (r)", "Reconversion (r)", "Storage (r)"), "Ammonia with cracking (r)", NA))


dfNH3C_long_20000 <- dfNH3C_long[, c("reference", "value", "variable", "scenario")]


#Merge the dataframes
database_long_20000 <- rbind(dfLH2_long_20000, dfNH3S_long_20000, dfNH3C_long_20000)

database_long_20000$distance <- "20,000"


## 500 km 

# Add components for conversion step pipeline 500km
dfbase$EF_production_pipe_500_r <- dfbase$EF_pipe_H2prod_tot_500
dfbase$EF_conversion_pipe_500_n <- dfbase$EF_pipe_comp1
dfbase$EF_conversion_pipe_500_r <- dfbase$EF_pipe_comp1_tot_500
dfbase$EF_transport_pipe_500_n <- dfbase$EF_pipeline_500
dfbase$EF_transport_pipe_500_r <- dfbase$EF_pipeline_tot_500
dfbase$EF_reconversion_pipe_500_n <- dfbase$EF_pipe_comp2
dfbase$EF_reconversion_pipe_500_r <- dfbase$EF_pipe_comp2
dfbase$EF_storage_pipe_500_n <- dfbase$EF_pipe_storage
dfbase$EF_storage_pipe_500_r <- dfbase$EF_pipe_storage


# Select the relevant columns from the database
dfpipe_long <- gather(dfbase, key = "variable", value = "value", 
                      EF_production, EF_production_pipe_500_r, EF_conversion_pipe_500_n, EF_conversion_pipe_500_r,
                      EF_transport_pipe_500_n, EF_transport_pipe_500_r, EF_reconversion_pipe_500_n, EF_reconversion_pipe_500_r,
                      EF_storage_pipe_500_n, EF_storage_pipe_500_r)

# To go from g to kg emissions 
dfpipe_long$value <- dfpipe_long$value/1000

# Rename the selected columns for each of the process steps
dfpipe_long$variable <- ifelse(dfpipe_long$variable == "EF_production", "Production (n)",
                               ifelse(dfpipe_long$variable == "EF_production_pipe_500_r", "Production (r)",
                                      ifelse(dfpipe_long$variable == "EF_conversion_pipe_500_n", "Conversion (n)",
                                             ifelse(dfpipe_long$variable == "EF_conversion_pipe_500_r", "Conversion (r)",
                                                    ifelse(dfpipe_long$variable == "EF_transport_pipe_500_n", "Transport (n)",
                                                           ifelse(dfpipe_long$variable == "EF_transport_pipe_500_r", "Transport (r)",
                                                                  ifelse(dfpipe_long$variable == "EF_reconversion_pipe_500_n", "Reconversion (n)",
                                                                         ifelse(dfpipe_long$variable == "EF_reconversion_pipe_500_r", "Reconversion (r)",
                                                                                ifelse(dfpipe_long$variable == "EF_storage_pipe_500_n", "Storage (n)",
                                                                                       ifelse(dfpipe_long$variable == "EF_storage_pipe_500_r", "Storage (r)", NA))))))))))


dfpipe_long$scenario <- ifelse(dfpipe_long$variable %in% c("Production (n)", "Conversion (n)", "Transport (n)", "Reconversion (n)", "Storage (n)"), "Pipeline (n)",
                               ifelse(dfpipe_long$variable %in% c("Production (r)", "Conversion (r)", "Transport (r)", "Reconversion (r)", "Storage (r)"), "Pipeline (r)", NA))


dfpipe_long_500 <- dfpipe_long[, c("reference", "value", "variable", "scenario")]

database_long_500 <- dfpipe_long_500

database_long_500$distance <- "500"


#Merge the dataframes, without ammonia without cracking
database_long <- rbind(database_long_500, database_long_1000, database_long_5000, database_long_20000)


database_long <- subset(database_long, scenario %in% c("Pipeline (r)", "Liquid hydrogen (r)", "Ammonia with cracking (r)") )


# Rename the levels in the scenario column
database_long$scenario <- factor(database_long$scenario, levels = c("Pipeline (r)", "Liquid hydrogen (r)", "Ammonia with cracking (r)"),
                                 labels = c("Pipeline", "Liquid hydrogen", "Ammonia"))

# Set the order of the steps
custom_order_steps <- rev(c("Production (r)", "Conversion (r)", "Transport (r)", 
                            "Reconversion (r)", "Storage (r)"))

database_long$variable <- factor(database_long$variable, levels = custom_order_steps)

# Set the order of the scenarios
custom_order_scenarios <- c("Pipeline", "Liquid hydrogen", 
                            "Ammonia")

database_long$scenario <- factor(database_long$scenario, levels = custom_order_scenarios)


custom_order_distance <- c("500", "1,000", "5,000", "20,000")
database_long$distance <- factor(database_long$distance, levels = custom_order_distance)


# create figure
stacks_distances <- ggplot(database_long, aes(x = distance, y = value, fill = variable)) +
  stat_summary(geom = "bar", fun = median, position = "stack", color = "black", linewidth = 0.05) + 
  scale_fill_manual(name = "",
                    values = c("Production (r)" = "#66c2a5", "Conversion (r)" = "#fc8d62", 
                               "Transport (r)" = "#8da0cb","Reconversion (r)" = "#e78ac3", "Storage (r)" = "#a6d854"),
                    breaks = c("Storage (r)", "Reconversion (r)", "Transport (r)", "Conversion (r)", "Production (r)"),
                    labels = c("Storage", "Reconversion", "Transport", "Conversion", "Production")) +
  scale_y_continuous(breaks = seq(0, 25, by = 1), expand = c(0, 0), limits = c(0, NA)) +
  coord_cartesian(ylim = c(0, 9.25)) +
  facet_grid(. ~ scenario, scales = "free_x", space = "free_x", switch = "x", labeller = label_bquote(cols = .)) +
  ylab(expression(paste("Cradle-to-delivery emissions (kgCO"[2]*"-e per kg H"[2]*")"))) +
  xlab("Transport distance (km)") +
  theme(panel.background = element_rect(fill = "white"),
        strip.text = element_blank(),          # Hide the facet labels
        axis.text.x = element_text(angle = 45, hjust = 1, size = 22, vjust = 1, color = "black"), # Tilt and adjust x-axis tick labels
        legend.text = element_text(size = 28),
        legend.key.size = unit(1, "lines"),
        legend.text.align = 0,
        axis.line = element_line(linewidth = 0.2),
        axis.ticks = element_line(linewidth = 0.2),
        text = element_text(family = "Jost", size = 28, color = "black"),
        legend.title = element_blank(),
        legend.background = element_rect(fill = "white"))

stacks_distances


ggsave("Figures/Figure4B.tiff", stacks_distances, width = 9, height = 8.2, units = "cm", dpi = 300)


#and only ammonia without cracking for the supplementary information figure
#Merge the dataframes
database_long <- rbind(database_long_500, database_long_1000, database_long_5000, database_long_20000)


database_long <- subset(database_long, scenario %in% c("Ammonia without cracking (r)") )


# Rename the levels in the scenario column
database_long$scenario <- factor(database_long$scenario, levels = c("Ammonia without cracking (r)"),
                                 labels = c("Ammonia without cracking"))

# Set the order of the steps
custom_order_steps <- rev(c("Production (r)", "Conversion (r)", "Transport (r)", 
                            "Reconversion (r)", "Storage (r)"))

database_long$variable <- factor(database_long$variable, levels = custom_order_steps)

# Set the order of the scenarios
custom_order_scenarios <- c("Ammonia without")

database_long$scenario <- factor(database_long$scenario, levels = custom_order_scenarios)


custom_order_distance <- c("500", "1,000", "5,000", "20,000")
database_long$distance <- factor(database_long$distance, levels = custom_order_distance)

# create figure
stacks_distances_NH3 <- ggplot(database_long, aes(x = distance, y = value, fill = variable)) +
  stat_summary(geom = "bar", fun = median, position = "stack", color = "black", linewidth = 0.05) + 
  scale_fill_manual(name = "",
                    values = c("Production (r)" = "#66c2a5", "Conversion (r)" = "#fc8d62", 
                               "Transport (r)" = "#8da0cb","Storage (r)" = "#a6d854"),
                    breaks = c("Storage (r)", "Transport (r)", "Conversion (r)", "Production (r)"),
                    labels = c("Storage", "Transport", "Conversion", "Production")) +
  scale_y_continuous(breaks = seq(0, 25, by = 1), expand = c(0, 0), limits = c(0, NA)) +
  coord_cartesian(ylim = c(0, 6)) +
  facet_grid(. ~ scenario, scales = "free_x", space = "free_x", switch = "x", labeller = label_bquote(cols = .)) +
  ylab(expression(paste("Cradle-to-delivery emissions (kgCO"[2]*"-e per kg H"[2]*"-eq.)"))) +
  xlab("Transport distance (km)") +
  theme(panel.background = element_rect(fill = "white"),
        strip.text = element_blank(),          # Hide the facet labels
        axis.text.x = element_text(angle = 45, hjust = 1, size = 22, vjust = 1, color = "black"), # Tilt and adjust x-axis tick labels
        legend.text = element_text(size = 28),
        legend.key.size = unit(1, "lines"),
        legend.text.align = 0,
        axis.line = element_line(linewidth = 0.2),
        axis.ticks = element_line(linewidth = 0.2),
        text = element_text(family = "Jost", size = 28, color = "black"),
        legend.title = element_blank(),
        legend.background = element_rect(fill = "white"))

stacks_distances_NH3


ggsave("Figures/SIFigure5.tiff", stacks_distances_NH3, width = 6, height = 8.5, units = "cm", dpi = 300)


