library(ggplot2)
library(showtext)
library(gridExtra)

# Set working directory
setwd("")

font_add("Jost", regular = "Scripts/Jost/Jost-400-Book.ttf")
showtext_auto() # turn on showtext auto mode
theme_set(theme_classic(base_family = "Jost")) # set Jost as the base font family

# This script is to create greenhouse gas emission-supply curves for production + transport
# all electricity soruces together, but using different transport types

# Read emissions data for green hydrogen production for the grid-connected: power export configuration
dfbase <- read.csv("Derived_data/database_results.csv")

# ammonia production emissions are between 2.0 and 2.5 kgCO2e per kg NH3
ratio_H2_NH3 <- 2.016 * 1.5 / 17.031

# Use 1000 km distance
# Sort database by footprint in ascending order
sorted_EF_pipe_lifecycle_1000 <- dfbase[order(dfbase$EF_pipe_lifecycle_1000), ]

# Create a vector to store the cumulative capacity
cumul_ktH2y <- rep(0, nrow(sorted_EF_pipe_lifecycle_1000))
ktH2ycalc <- rep(0, nrow(sorted_EF_pipe_lifecycle_1000))

# Loop through each row of the database
for (i in 2:nrow(sorted_EF_pipe_lifecycle_1000)) {
  # Get the capacity of the project with lowest footprint
  cumul_ktH2y[1] <- ktH2ycalc[1]
  ktH2ycalc[i] <- sorted_EF_pipe_lifecycle_1000[i, "cap.ktH2_calc"]
  cumul_ktH2y[i] <- ktH2ycalc[i] + cumul_ktH2y[i - 1]
}

# Add to database
sorted_EF_pipe_lifecycle_1000$cumul_ktH2y <- as.numeric(cumul_ktH2y)
sorted_EF_pipe_lifecycle_1000$type <- "Pipeline"
sorted_EF_pipe_lifecycle_1000$EF_lifecycle_1000 <- sorted_EF_pipe_lifecycle_1000$EF_pipe_lifecycle_1000

sorted_EF_pipe_lifecycle_1000 <- sorted_EF_pipe_lifecycle_1000[, c("reference", "cumul_ktH2y", "EF_lifecycle_1000", "electricity.source", "type")]

# Sort database by footprint in ascending order
sorted_EF_LH2_lifecycle_1000 <- dfbase[order(dfbase$EF_LH2_lifecycle_1000), ]

# Create a vector to store the cumulative capacity
cumul_ktH2y <- rep(0, nrow(sorted_EF_LH2_lifecycle_1000))
ktH2ycalc <- rep(0, nrow(sorted_EF_LH2_lifecycle_1000))

# Loop through each row of the database
for (i in 2:nrow(sorted_EF_LH2_lifecycle_1000)) {
  # Get the capacity of the project with lowest footprint
  cumul_ktH2y[1] <- ktH2ycalc[1]
  ktH2ycalc[i] <- sorted_EF_LH2_lifecycle_1000[i, "cap.ktH2_calc"]
  cumul_ktH2y[i] <- ktH2ycalc[i] + cumul_ktH2y[i - 1]
}

# Add to database
sorted_EF_LH2_lifecycle_1000$cumul_ktH2y <- as.numeric(cumul_ktH2y)
sorted_EF_LH2_lifecycle_1000$type <- "Liquid hydrogen"
sorted_EF_LH2_lifecycle_1000$EF_lifecycle_1000 <- sorted_EF_LH2_lifecycle_1000$EF_LH2_lifecycle_1000

sorted_EF_LH2_lifecycle_1000 <- sorted_EF_LH2_lifecycle_1000[, c("reference", "cumul_ktH2y", "EF_lifecycle_1000", "electricity.source", "type")]

# Sort database by footprint in ascending order
sorted_EF_lifecycle_H2_NH3_1S_1000 <- dfbase[order(dfbase$EF_lifecycle_H2_NH3_1S_1000), ]

# Create a vector to store the cumulative capacity
cumul_ktH2y <- rep(0, nrow(sorted_EF_lifecycle_H2_NH3_1S_1000))
ktH2ycalc <- rep(0, nrow(sorted_EF_lifecycle_H2_NH3_1S_1000))

# Loop through each row of the database
for (i in 2:nrow(sorted_EF_lifecycle_H2_NH3_1S_1000)) {
  # Get the capacity of the project with lowest footprint
  cumul_ktH2y[1] <- ktH2ycalc[1]
  ktH2ycalc[i] <- sorted_EF_lifecycle_H2_NH3_1S_1000[i, "cap.ktH2_calc"]
  cumul_ktH2y[i] <- ktH2ycalc[i] + cumul_ktH2y[i - 1]
}

# Add to database
sorted_EF_lifecycle_H2_NH3_1S_1000$cumul_ktH2y <- as.numeric(cumul_ktH2y)
sorted_EF_lifecycle_H2_NH3_1S_1000$type <- "Ammonia with storage"
sorted_EF_lifecycle_H2_NH3_1S_1000$EF_lifecycle_1000 <- sorted_EF_lifecycle_H2_NH3_1S_1000$EF_lifecycle_H2_NH3_1S_1000

sorted_EF_lifecycle_H2_NH3_1S_1000 <- sorted_EF_lifecycle_H2_NH3_1S_1000[, c("reference", "cumul_ktH2y", "EF_lifecycle_1000", "electricity.source", "type")]


# Sort database by footprint in ascending order
sorted_EF_lifecycle_H2_NH3_1C_1000 <- dfbase[order(dfbase$EF_lifecycle_H2_NH3_1C_1000), ]

# Create a vector to store the cumulative capacity
cumul_ktH2y <- rep(0, nrow(sorted_EF_lifecycle_H2_NH3_1C_1000))
ktH2ycalc <- rep(0, nrow(sorted_EF_lifecycle_H2_NH3_1C_1000))

# Loop through each row of the database
for (i in 2:nrow(sorted_EF_lifecycle_H2_NH3_1C_1000)) {
  # Get the capacity of the project with lowest footprint
  cumul_ktH2y[1] <- ktH2ycalc[1]
  ktH2ycalc[i] <- sorted_EF_lifecycle_H2_NH3_1C_1000[i, "cap.ktH2_calc"]
  cumul_ktH2y[i] <- ktH2ycalc[i] + cumul_ktH2y[i - 1]
}

# Add to database
sorted_EF_lifecycle_H2_NH3_1C_1000$cumul_ktH2y <- as.numeric(cumul_ktH2y)
sorted_EF_lifecycle_H2_NH3_1C_1000$type <- "Ammonia with cracking"
sorted_EF_lifecycle_H2_NH3_1C_1000$EF_lifecycle_1000 <- sorted_EF_lifecycle_H2_NH3_1C_1000$EF_lifecycle_H2_NH3_1C_1000

sorted_EF_lifecycle_H2_NH3_1C_1000 <- sorted_EF_lifecycle_H2_NH3_1C_1000[, c("reference", "cumul_ktH2y", "EF_lifecycle_1000", "electricity.source", "type")]

# Combine the dataframes
combined_transport_EF <- rbind(sorted_EF_pipe_lifecycle_1000, sorted_EF_LH2_lifecycle_1000, 
                               sorted_EF_lifecycle_H2_NH3_1S_1000, sorted_EF_lifecycle_H2_NH3_1C_1000)

# ESC with benchmarks
ESC_lifecycle_1000_MtH2 <- ggplot() + 
  geom_hline(aes(yintercept = 4, linetype = "UK renewable"), color = "#391838", linewidth = 0.5) +
  geom_hline(aes(yintercept = 3.38, linetype = "EU commission"), color = "#81377f", linewidth = 0.5) +
  geom_line(data = combined_transport_EF, aes(x = cumul_ktH2y/1000, y = EF_lifecycle_1000/1000, linetype = type), color = "black", linewidth = 0.5) +
  xlab(expression(paste("Cumulative production rate (Mt H"[2]*" per year)"))) +
  ylab(expression(paste("Cradle-to-delivery emissions (kgCO"[2]*"-e per kg H"[2]*")"))) +
  scale_x_continuous(breaks = seq(0, max(combined_transport_EF$cumul_ktH2y/1000) + 10, by = 10), expand = c(0, 0), limits = c(0, NA)) +
  scale_y_continuous(breaks = seq(0, max(combined_transport_EF$EF_lifecycle_1000/1000), by = 2), expand = c(0, 0), limits = c(0, NA)) +
  coord_cartesian(xlim = c(0, 70), ylim = c(0, 12))+
  scale_linetype_manual(name = "Cradle-to-delivery benchmark",
                        values = c("Pipeline" = "solid", "Liquid hydrogen" = "dashed", "Ammonia with cracking" = "dotted", 
                                   "UK renewable" = "solid", "EU commission" = "solid"),
                        labels = expression("Pipeline", "Liquid H"[2]*" shipping", "Ammonia shipping",
                                            "UK renewable transport fuel", "EU renewable H"[2]*""),                        
                        guide = guide_legend(override.aes = list(color = c("black", "black", "black", 
                                                                           "#391838", "#81377f"), 
                                                                 linetype = c("solid", "dashed", "dotted", 
                                                                              "solid", "solid"))))+
  theme_classic() +
  theme(
    text = element_text(family = "Jost", size = 32, color = "black"),
    legend.text = element_text(size = 28),
    legend.key.size = unit(1, "lines"),
    legend.text.align = 0,
    legend.background = element_rect(fill = "white", color = "white"),  # Set legend background to white
    legend.box.background = element_blank(),  # Remove the box around the legend
    axis.line = element_line(linewidth = 0.2),
    axis.ticks = element_line(linewidth = 0.2))

ggsave("Figures/Figure6B.tiff", ESC_lifecycle_1000_MtH2 + 
         guides(color = "none", linetype = "none"), width = 6.5, height = 8, units = "cm", dpi = 300)


##########20,000

# use 20,000 km as distance.

# Sort database by footprint in ascending order
sorted_EF_LH2_lifecycle_20000 <- dfbase[order(dfbase$EF_LH2_lifecycle_20000), ]

# Create a vector to store the cumulative capacity
cumul_ktH2y <- rep(0, nrow(sorted_EF_LH2_lifecycle_20000))
ktH2ycalc <- rep(0, nrow(sorted_EF_LH2_lifecycle_20000))

# Loop through each row of the database
for (i in 2:nrow(sorted_EF_LH2_lifecycle_20000)) {
  # Get the capacity of the project with lowest footprint
  cumul_ktH2y[1] <- ktH2ycalc[1]
  ktH2ycalc[i] <- sorted_EF_LH2_lifecycle_20000[i, "cap.ktH2_calc"]
  cumul_ktH2y[i] <- ktH2ycalc[i] + cumul_ktH2y[i - 1]
}

# Add to database
sorted_EF_LH2_lifecycle_20000$cumul_ktH2y <- as.numeric(cumul_ktH2y)
sorted_EF_LH2_lifecycle_20000$type <- "Liquid hydrogen"
sorted_EF_LH2_lifecycle_20000$EF_lifecycle_20000 <- sorted_EF_LH2_lifecycle_20000$EF_LH2_lifecycle_20000

sorted_EF_LH2_lifecycle_20000 <- sorted_EF_LH2_lifecycle_20000[, c("reference", "cumul_ktH2y", "EF_lifecycle_20000", "electricity.source", "type")]



# Sort database by footprint in ascending order
sorted_EF_lifecycle_H2_NH3_1S_20000 <- dfbase[order(dfbase$EF_lifecycle_H2_NH3_1S_20000), ]

# Create a vector to store the cumulative capacity
cumul_ktH2y <- rep(0, nrow(sorted_EF_lifecycle_H2_NH3_1S_20000))
ktH2ycalc <- rep(0, nrow(sorted_EF_lifecycle_H2_NH3_1S_20000))

# Loop through each row of the database
for (i in 2:nrow(sorted_EF_lifecycle_H2_NH3_1S_20000)) {
  # Get the capacity of the project with lowest footprint
  cumul_ktH2y[1] <- ktH2ycalc[1]
  ktH2ycalc[i] <- sorted_EF_lifecycle_H2_NH3_1S_20000[i, "cap.ktH2_calc"]
  cumul_ktH2y[i] <- ktH2ycalc[i] + cumul_ktH2y[i - 1]
}

# Add to database
sorted_EF_lifecycle_H2_NH3_1S_20000$cumul_ktH2y <- as.numeric(cumul_ktH2y)
sorted_EF_lifecycle_H2_NH3_1S_20000$type <- "Ammonia with storage"
sorted_EF_lifecycle_H2_NH3_1S_20000$EF_lifecycle_20000 <- sorted_EF_lifecycle_H2_NH3_1S_20000$EF_lifecycle_H2_NH3_1S_20000

sorted_EF_lifecycle_H2_NH3_1S_20000 <- sorted_EF_lifecycle_H2_NH3_1S_20000[, c("reference", "cumul_ktH2y", "EF_lifecycle_20000", "electricity.source", "type")]


# Sort database by footprint in ascending order
sorted_EF_lifecycle_H2_NH3_1C_20000 <- dfbase[order(dfbase$EF_lifecycle_H2_NH3_1C_20000), ]

# Create a vector to store the cumulative capacity
cumul_ktH2y <- rep(0, nrow(sorted_EF_lifecycle_H2_NH3_1C_20000))
ktH2ycalc <- rep(0, nrow(sorted_EF_lifecycle_H2_NH3_1C_20000))

# Loop through each row of the database
for (i in 2:nrow(sorted_EF_lifecycle_H2_NH3_1C_20000)) {
  # Get the capacity of the project with lowest footprint
  cumul_ktH2y[1] <- ktH2ycalc[1]
  ktH2ycalc[i] <- sorted_EF_lifecycle_H2_NH3_1C_20000[i, "cap.ktH2_calc"]
  cumul_ktH2y[i] <- ktH2ycalc[i] + cumul_ktH2y[i - 1]
}

# Add to database
sorted_EF_lifecycle_H2_NH3_1C_20000$cumul_ktH2y <- as.numeric(cumul_ktH2y)
sorted_EF_lifecycle_H2_NH3_1C_20000$type <- "Ammonia with cracking"
sorted_EF_lifecycle_H2_NH3_1C_20000$EF_lifecycle_20000 <- sorted_EF_lifecycle_H2_NH3_1C_20000$EF_lifecycle_H2_NH3_1C_20000

sorted_EF_lifecycle_H2_NH3_1C_20000 <- sorted_EF_lifecycle_H2_NH3_1C_20000[, c("reference", "cumul_ktH2y", "EF_lifecycle_20000", "electricity.source", "type")]

# Combine the dataframes
combined_transport_EF <- rbind(sorted_EF_LH2_lifecycle_20000, 
                               sorted_EF_lifecycle_H2_NH3_1S_20000, sorted_EF_lifecycle_H2_NH3_1C_20000)

# ESC with benchmarks
ESC_lifecycle_20000_MtH2 <- ggplot() + 
  geom_hline(aes(yintercept = 4, linetype = "UK renewable"), color = "#391838", linewidth = 0.5) +
  geom_hline(aes(yintercept = 3.38, linetype = "EU commission"), color = "#81377f", linewidth = 0.5) +
  geom_line(data = combined_transport_EF, aes(x = cumul_ktH2y/1000, y = EF_lifecycle_20000/1000, linetype = type), color = "black", linewidth = 0.5) +
  xlab(expression(paste("Cumulative production rate (Mt H"[2]*" per year)"))) +
  ylab(expression(paste("Cradle-to-delivery emissions (kgCO"[2]*"-e per kg H"[2]*")"))) +
  scale_x_continuous(breaks = seq(0, max(combined_transport_EF$cumul_ktH2y/1000) + 10, by = 10), expand = c(0, 0), limits = c(0, NA)) +
  scale_y_continuous(breaks = seq(0, max(combined_transport_EF$EF_lifecycle_20000/1000), by = 2), expand = c(0, 0), limits = c(0, NA)) +
  coord_cartesian(xlim = c(0, 70), ylim = c(0, 12))+
  scale_linetype_manual(name = "Cradle-to-delivery benchmark",
                        values = c("Liquid hydrogen" = "dashed", "Ammonia with cracking" = "dotted", 
                                   "UK renewable" = "solid", "EU commission" = "solid"),
                        labels = expression("Liquid H"[2]*" shipping", "Ammonia shipping",
                                            "UK renewable transport fuel", "EU renewable H"[2]*""),                        
                        guide = guide_legend(override.aes = list(color = c("black", "black", 
                                                                           "#391838", "#81377f"), 
                                                                 linetype = c("dashed", "dotted", 
                                                                              "solid", "solid"))))+
  theme_classic() +
  theme(
    text = element_text(family = "Jost", size = 32, color = "black"),
    legend.text = element_text(size = 28),
    legend.key.size = unit(1, "lines"),
    legend.text.align = 0,
    legend.background = element_rect(fill = "white", color = "white"),  # Set legend background to white
    legend.box.background = element_blank(),  # Remove the box around the legend
    axis.line = element_line(linewidth = 0.2),
    axis.ticks = element_line(linewidth = 0.2))


ggsave("Figures/Figure6C.tiff", ESC_lifecycle_20000_MtH2 + guides(color = "none", linetype = "none"), width =6.5, height = 8, units = "cm", dpi = 300)
